m = 0; % mean = zero
STD = 1; % standard deviation = 1;
x= -5:.1:5; % data range for normal dist plot

figure;hold on
plot(x,normpdf(x,m,STD))
plot(x,normpdf(x,m+.5,STD))

%% MAKE DATASET

Nt1 = 100;
Nt2 = 100;

data1 = repmat(normpdf(x,m,STD)',1,Nt1); % figure;imagesc(data1')
data1 = data1+randn(size(data1))./10; % add Gaussian noise
data2 = repmat(normpdf(x,m+.5,STD)',1,Nt2); % figure;imagesc(data2')
data2 = data2+randn(size(data2))./10; % add Gaussian noise

[H,orip,CI,stats] = ttest2(data1,data2,0.05,[],'unequal',2);
orit = stats.tstat;

mdata1=mean(data1,2);
mdata2=mean(data2,2);
diff=mdata1-mdata2;

figure;set(gcf,'Color','w')
subplot(1,3,1)
imagesc(data1')
subplot(1,3,2)
imagesc(data2')
subplot(1,3,3)
hold on
plot(x,mdata1,'k','LineWidth',2)
plot(x,mdata2,'g','LineWidth',2)
plot(x,diff,'r','LineWidth',2)
axis tight;v=axis;
plot(x,(orip<=0.05).*20-20-0.14,'r.','MarkerSize',10)
axis([v(1) v(2) -0.15 v(4)])
box on

Nf = size(data1,1);

%% do bootstrap

b = 1000;
alpha = .05;
th = b*(1-alpha);
% lo = round(b*alpha./2);
% hi = b-lo;
% lo = lo+1;

boott = zeros(Nf,b);
bootp = boott;
cdata1 = data1-repmat(mean(data1,2),[1 Nt1]);
cdata2 = data2-repmat(mean(data2,2),[1 Nt2]);

for kk=1:b
    [H,bootp(:,kk),CI,stats] = ttest2(cdata1(:,randi(Nt1,Nt1,1)),cdata2(:,randi(Nt2,Nt2,1)),0.05,[],'unequal',2);
    boott(:,kk) = stats.tstat;
end
    
%% get bootstrap univariate thresholds

% IMPORTANT: as you will see, on it's own the bootstrap DOES NOT
%            correct for multiple comparisons

sortboot = sort(boott.^2,2); % we use t.^2 (=F) to make our life easier
unibootth = sortboot(:,th); 

figure;set(gcf,'Color','w')
hold on
plot(x,mdata1,'k','LineWidth',2)
plot(x,mdata2,'g','LineWidth',2)
plot(x,diff,'r','LineWidth',2)
axis tight;v=axis;
plot(x,(orit.^2>=unibootth).*20-20-0.14,'r.','MarkerSize',10)
axis([v(1) v(2) -0.15 v(4)])
box on

%% get cluster threshold

clusterbootth = limo_ecluster_make(boott.^2,bootp,alpha);

%% cluster original data

sigcluster = limo_ecluster_test(orit'.^2,orip',clusterbootth,alpha);

%% plot results

figure;set(gcf,'Color','w')
hold on
plot(x,mdata1,'k','LineWidth',2)
plot(x,mdata2,'g','LineWidth',2)
plot(x,diff,'r','LineWidth',2)
axis tight;v=axis;
plot(x,sigcluster.elec_mask.*20-20-0.14,'r.','MarkerSize',10)
axis([v(1) v(2) -0.15 v(4)])
box on


