%% erp_workshop_10_anova

%% extension of the bootstrap-t technique to ANOVA

%% GET DATA FOR 2x2 DESIGN
% we use our original dataset to create two matching conditions so that we
% know we have an interaction

c1=zeros(1,451,20); % reformat data so that dimension 1 = 1 electrode
c1(1,:,:)=erpm(:,:,1);c2(1,:,:)=erpm(:,:,2);
Xf=-300:2:600; % time vector
Ns=size(erpm,2);

% create 2 conditions with controlled effect in given time window
c3=c1+randn(size(c1))*.5;c4=c2+randn(size(c2))*.5;
tw=[72 600]; % << choose time window in which effect occurs
tw=Xf>=tw(1) & Xf<=tw(2); % logical vector of selected time points
c3(1,tw,:)=c1(1,tw,:).*1.2;
c4(1,tw,:)=c2(1,tw,:).*1.5;

data=zeros(size(c1,2),size(c1,3),4);
data(:,:,1)=c1; % A1B1
data(:,:,2)=c2; % A1B2
data(:,:,3)=c3; % A2B1
data(:,:,4)=c4; % A2B2

%% PLOT DATA

figure('Color','w','NumberTitle','off')

subplot(2,1,1);hold on 

plot(Xf,mean(data(:,:,1),2),'k','LineWidth',2) % c1
plot(Xf,mean(data(:,:,2),2),'k--','LineWidth',2) % c2
plot(Xf,mean(data(:,:,3),2),'Color',[.7 .7 .7],'LineStyle','-','LineWidth',2) % c3
plot(Xf,mean(data(:,:,4),2),'Color',[.7 .7 .7],'LineStyle','--','LineWidth',2) % c4

legend('c1','c2','c3','c4')
set(gca,'LineWidth',1,'FontSize',14)
set(gca,'XLim',[-300 600],'Layer','top')
xlabel('Time in ms','FontSize',16)
ylabel('Mean ERPs','FontSize',16)
box on;axis tight

subplot(2,1,2);hold on 

plot(Xf,mean(data(:,:,1),2)-mean(data(:,:,2),2),'k','LineWidth',2) % c1-c2
plot(Xf,mean(data(:,:,3),2)-mean(data(:,:,4),2),'Color',[.7 .7 .7],'LineStyle','-','LineWidth',2) % c3-c4

legend('c1-c2','c3-c4')
set(gca,'LineWidth',1,'FontSize',14)
set(gca,'XLim',[-300 600],'Layer','top')
xlabel('Time in ms','FontSize',16)
ylabel('Mean ERPs','FontSize',16)
box on

%% RUN ANOVA

result = limo_rep_anova(data,[],[2 2]);

%% LOOK AT RESULTS

figure('Color','w','NumberTitle','off');hold on 

plot(Xf,result.F,'LineWidth',2)
legend(result.names)
set(gca,'LineWidth',1,'FontSize',14)
set(gca,'XLim',[-300 600],'Layer','top')
xlabel('Time in ms','FontSize',16)
ylabel('F values','FontSize',16)
box on

%% BOOTSTRAP ANOVA

% The extension to bootstrap anova is left as an exercise.

% Or you can use limo_random_robust

% The starting point is always the same:
% center each cell independently

% So in our 2x2 example:

cdata=data-repmat(mean(data,2),[1 Ns 1]);

% you can check that each cell now has a mean of zero:
% figure;plot(Xf,mean(squeeze(cdata(:,:,1)),2))

% Then sample subjects with replacements and proceed as we did with the
% t-test.



