%% erp_workshop_11_ancova

%% *******************************************
%% LOAD DATA

% We load S1 or S2:
S=1;
load([filepath,'S',num2str(S),'_1elec_epoch_ancova'])
% load S1_1elec_epoch_ancova.mat

% data structure contains these fields:
% data.ERP - one electrode only
% data.Xf - time vector for plots
% data.design - original design matrix

Xf=data.Xf;
alpha=0.05;

%% *******************************************
%% MAKE LIMO DESIGN MATRIX

Ne = size(data.ERP,1); % electrodes
Nf = size(data.ERP,2); % time frames
Nt = size(data.ERP,3); % trials

% create directory for LIMO
cd(filepath)
mkdir('S1')

% make design matrix
[X,nb_conditions,nb_interactions,nb_continuous] = ...
    limo_design_matrix(data.ERP,data.design(:,1),data.design(:,2:5),'S1',0,0,1); % no zcore

%% *******************************************
%% PERFORM LINEAR REGRESSION

% fit model to data using limo_glm1
load Yr
Y = squeeze(Yr)';
model = limo_glm1(Y,X,nb_conditions,nb_interactions,nb_continuous,'OLS','Time',[],Nf);

% model =
%
%     R2_univariate: [411x1 double]
%                 F: [411x1 double]
%                 p: [411x1 double]
%             betas: [13x411 double]
%                df: [11 921]
%        conditions: [1x1 struct]
%        continuous: [1x1 struct]

%% RESULTS: OVERALL MODEL FIT

figure('Color','w','NumberTitle','off');hold on
plot(Xf,model.R2_univariate,'k','LineStyle','-','LineWidth',2)
v=axis;
plot(Xf,(model.p<alpha)*2-2,'r.','MarkerSize',10)
axis(v);
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 400])
box on

%% RESULTS: BETA COEFFICIENTS

figure('Color','w','NumberTitle','off');hold on
plot(Xf,mean(model.betas([9 11],:),1),'r','LineStyle','-','LineWidth',2) % identity task
plot(Xf,mean(model.betas([10 12],:),1),'g','LineStyle','-','LineWidth',2) % colour task

legend('identity','colour')

set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 400])
box on

%% *******************************************
%% PERFORM LINEAR CONTRASTS

% IMAGE STRUCTURE sensitivity in the IDENTITY TASK
con_str_ID_weights=[0 0 0 0 0 0 0 0 1 0 1 0 0];

% IMAGE STRUCTURE sensitivity in the COLOUR TASK
con_str_CO_weights=[0 0 0 0 0 0 0 0 0 1 0 1 0];

% IMAGE STRUCTURE sensitivity in 2 tasks
con_str_weights = [0 0 0 0 0 0 0 0 1 -1 1 -1 0];

% ------------------------------------------------
% CONTRASTS --------------------------------------
% ------------------------------------------------

R = eye(size(Y,1)) - (X*pinv(X));
var = ((R*Y)'*(R*Y)) / model.df(2);

% ------------------------------------------------
% IMAGE STRUCTURE sensitivity in the IDENTITY TASK
C=con_str_ID_weights;
con_str_ID = C*model.betas; % contrast
con_str_ID_T = (C*model.betas) ./ sqrt(diag(var)'.*(C*pinv(X'*X)*C')); % t statistics
con_str_ID_p = 2*(1-tcdf(abs(con_str_ID_T), model.df(2))); % F test p value

% ------------------------------------------------
% IMAGE STRUCTURE sensitivity in the COLOUR TASK
C=con_str_CO_weights;
con_str_CO = C*model.betas; % contrast
con_str_CO_T = (C*model.betas) ./ sqrt(diag(var)'.*(C*pinv(X'*X)*C')); % t statistics
con_str_CO_p = 2*(1-tcdf(abs(con_str_CO_T), model.df(2))); % F test p value

% ------------------------------------------------
% IMAGE STRUCTURE sensitivity in 2 tasks: contrast F 0 0 0 0 0 0 0 0 1 -1 1 -1 0
% Evaluated after removing the mean difference between tasks, itself evaluated after removing
% the mean effect of noise.
C=con_str_weights;
con_str = C*model.betas; % contrast
con_str_T = (C*model.betas) ./ sqrt(diag(var)'.*(C*pinv(X'*X)*C')); % t statistics
con_str_p = 2*(1-tcdf(abs(squeeze(con_str_T)), model.df(2))); % F test p value
% ------------------------------------------------

%% RESULTS OF LINEAR CONTRASTS

figure('Color','w','NumberTitle','off');hold on
plot(Xf,con_str_ID,'r','LineStyle','-','LineWidth',2) % identity task
plot(Xf,con_str_CO,'g','LineStyle','-','LineWidth',2) % colour task
plot(Xf,con_str,'b','LineStyle','-','LineWidth',2) % difference

legend('identity','colour','difference')

v=axis;
plot(Xf,(con_str_ID_p<alpha)*100-100+v(3),'r.','MarkerSize',10) % identity task
plot(Xf,(con_str_CO_p<alpha)*100-100+v(3)*0.95,'g.','MarkerSize',10) % colour task
plot(Xf,(con_str_p<alpha)*100-100+v(3)*0.9,'b.','MarkerSize',10) % difference
axis(v);

set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 400])
box on

