%% erp_workshop_1_standard_figure

%% BEFORE YOU START

% Each cell (the beige area) can be evaluated by making a right click >
% Evaluate Current Cell, or by using these shortcuts:

% mac shortcut = command + enter
% pc shortcut = ctrl + enter

% You can navigate from cell to cell by clicking command+up arrow, or down arrow.

% Your task is to go through each cell, read and execute the code.

%% ------------------------------------------------------------------------
%% ADD EEGLAB AND LIMO_EEG TO YOUR PATH

% first save the eeglab folder 
% then, move the limo_eeg folder to eeglab/plugins/

% add the folders to your path:
addpath(genpath('/yourpath/eeglab/'));

% alternatively go to >Home >Set Path > Add with subfolders and choose the
% eeglab folder

% similarly, add the workshop directory and subdirectories to your path

%% ------------------------------------------------------------------------
%% LOAD DATA

% To load the data, you can:
%
% drag and drop the file erpm.mat into the command window;
%
% navigate through the browse menu accessed at the top of the interface;
%
% or directly through the command window:
%
% >> load erpm % if the file is in the current directory
% >> cd /yourpath/ % to change the current directory
% >> load /yourpath/erpm % if you need to specify the path

%% COMPUTE AVERAGES

C1=mean(erpm(:,:,1),2); % average across subjects for condition 1
C2=mean(erpm(:,:,2),2); % average across subjects for condition 2

Xf=-300:2:600; % time vector

%% MAKE STANDARD FIGURE

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)

%% MAKE BETTER STANDARD FIGURE

% you could change many plot properties -- see guidelines here:
% http://www.mathworks.co.uk/help/matlab/creating_plots/using-high-level-plotting-functions.html#f6-35125

% To change text properties, see:
% http://www.mathworks.co.uk/help/matlab/ref/text_props.html

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)

% Here we're going to add only few elements
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on

%% STATS

% We do a t-test at each time point & plot the results on the figure.
% This is done in one step using the function limo_yuend_ttest
% from the LIMO_EEG toolbox.
% >> help limo_yuend_ttest % to learn more about this function

c1=zeros(1,451,20);c2=c1; % reformat data so that dimension 1 = 1 electrode
% if we had say 100 electrodes, c1 would have dimensions 100,451,20

c1(1,:,:) = erpm(:,:,1); c2(1,:,:) = erpm(:,:,2);
percent = 0; % regular t-test
alpha = 0.05;
[Ty,diff,se,CI,p,tcrit,df] = limo_yuend_ttest(c1,c2,percent,alpha);

% We can also do a ttest on means using the function limo_ttest:
% [m,dfe,ci,sd,n,t,p] = limo_ttest(1,c1,c2,alpha);

% We could also use limo_rep_anova with one 2-level factor:
% data=zeros(size(c1,2),size(c1,3),2);
% data(:,:,1)=c1;data(:,:,2)=c2;
% result=limo_rep_anova(data,[],[2]);

%% ADD STATS TO STANDARD FIGURE

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on

% We add a horizontal line showing time points at which a significant mean
% difference was observed.
v=axis; % get current axis limits
alpha=0.05; % set alpha level
plot(Xf,(p<=alpha)*100-100+v(3)*.95,'r.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points


%% -----------------------------------------------------------------------
%% -----------------------------------------------------------------------
%% SAVE FIGURES TO DISK

% in the figure panel > File > Save as

% in a script, we can generate figures automatically:

%% SAVE FIGURES TO DISK - TIFF FORMAT

fileName = 'standard_figure.tiff'; 
set(gcf,'PaperPositionMode','auto')
print(gcf, '-dtiff','-r150', fileName); 

%% SAVE FIGURES TO DISK - EPS FORMAT

fileName = 'standard_figure.eps';
set(gcf,'PaperPositionMode','auto')
print(gcf, '-dpsc','-r150', fileName);





