%% erp_workshop_2_better_figure

%% ADD CONFIDENCE INTERVALS

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on

% get confidence intervals for each condition
percent=0;
alpha=0.05; % to get a 95% confidence interval
nullvalue=0;
[t,tmdata,trimci_c1,p,tcrit,df] = limo_trimci(c1, percent, alpha, nullvalue);
[t,tmdata,trimci_c2,p,tcrit,df] = limo_trimci(c2, percent, alpha, nullvalue);

% plot confidence intervals
plot(Xf,squeeze(trimci_c1),'Color',[0 0 0],'LineStyle','-','LineWidth',1)
plot(Xf,squeeze(trimci_c2),'Color',[.7 .7 .7],'LineStyle','--','LineWidth',1)

% plot results of t-test
[Ty,diff,se,CI,p,tcrit,df]=limo_yuend_ttest(c1,c2,percent,alpha);
v=axis; % get current axis limits
alpha=0.05; % set alpha level 
plot(Xf,(p<=alpha)*100-100+v(3)*.95,'r.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points

%% USE SHADED AREAS INSTEAD

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on

% plot confidence intervals
x = Xf; % time vector
y = squeeze(trimci_c1(:,:,1)); % CI lower bound
z=squeeze(trimci_c1(:,:,2)); % CI upper bound
c = 'c'; % set colour
t=.1; % set transparency [0, 1]
x=x(:)';y=y(:)';z=z(:)';
X=[x,fliplr(x)]; % create continuous x value array for plotting
Y=[y,fliplr(z)]; % create y values for out and then back
hf=fill(X,Y,c); % plot filled area
set(hf,'FaceAlpha',t,'EdgeColor',[0 0 0]);

y=squeeze(trimci_c2(:,:,1));z=squeeze(trimci_c2(:,:,2));
c='m';t=.1;
x=x(:)';y=y(:)';z=z(:)';
X=[x,fliplr(x)];%create continuous x value array for plotting
Y=[y,fliplr(z)];%create y values for out and then back
hf=fill(X,Y,c);%plot filled area
set(hf,'FaceAlpha',t,'EdgeColor',[.7 .7 .7]);

%% to export shaded areas with transparency:

set(gcf, 'renderer', 'painter') 
fname = 'figurewithshading.eps';
print(gcf, fname, '-depsc')


%% ADD DIFFERENCE AND ITS CONFIDENCE INTERVAL

figure('Color','w','NumberTitle','off') % make blank figure

subplot(2,1,1);hold on  % plot conditions 1 and 2 **********************

plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)

% get confidence intervals for each condition
percent=0;
alpha=0.05; % to get a 95% confidence interval
nullvalue=0;
[t,tmdata,trimci_c1,p,tcrit,df]=limo_trimci(c1, percent, alpha, nullvalue);
[t,tmdata,trimci_c2,p,tcrit,df]=limo_trimci(c2, percent, alpha, nullvalue);

% plot confidence intervals
plot(Xf,squeeze(trimci_c1),'Color',[0 0 0],'LineStyle','-','LineWidth',1)
plot(Xf,squeeze(trimci_c2),'Color',[.7 .7 .7],'LineStyle','--','LineWidth',1)

[Ty,diff,se,CI,p,tcrit,df]=limo_yuend_ttest(c1,c2,percent,alpha);

subplot(2,1,2);hold on % plot difference ********************************

plot(Xf,diff,'Color',[1 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,squeeze(CI),'Color',[1 0 0],'LineStyle','-','LineWidth',1)

v=axis; % get current axis limits
alpha=0.05; % set alpha level
plot(Xf,(p<=alpha)*100-100+v(3)*.95,'r.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points

plot([v(1) v(2)],[0 0],'k--') % add horizontal line at zero

for sub=1:2 % format 2 subplots
    subplot(2,1,sub)
    set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
    xlabel('Time in ms','FontSize',16)
    ylabel('Amplitude in \muV','FontSize',16)
    box on
end

%% HOW MANY SUBJECTS SHOW AN EFFECT?

figure('Color','w','NumberTitle','off') % make blank figure

% --------------------------------------------------------------------------
subplot(5,1,[1 2]);hold on  % plot conditions 1 and 2 **********************

plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',3)

% get confidence intervals for each condition
percent=0;
alpha=0.05; % to get a 95% confidence interval
nullvalue=0;
[t,tmdata,trimci_c1,p,tcrit,df]=limo_trimci(c1, percent, alpha, nullvalue);
[t,tmdata,trimci_c2,p,tcrit,df]=limo_trimci(c2, percent, alpha, nullvalue);

% plot confidence intervals
plot(Xf,squeeze(trimci_c1),'Color',[0 0 0],'LineStyle','-','LineWidth',1)
plot(Xf,squeeze(trimci_c2),'Color',[.7 .7 .7],'LineStyle','--','LineWidth',1)

[Ty,diff,se,CI,p,tcrit,df]=limo_yuend_ttest(c1,c2,percent,alpha);

set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
    xlabel('Time in ms','FontSize',16)
    ylabel('Amplitude in \muV','FontSize',16)
    box on

% --------------------------------------------------------------------------
subplot(5,1,[3 4]);hold on % plot difference ********************************

plot(Xf,squeeze(c1-c2),'Color',[.7 .7 .7]) % PLOT DIFFERENCE FOR EVERY SUBJECT <<<<

plot(Xf,diff,'Color',[1 0 0],'LineStyle','-','LineWidth',3)
plot(Xf,squeeze(CI),'Color',[1 0 0],'LineStyle','-','LineWidth',1)

v=axis; % get current axis limits
alpha=0.05; % set alpha level 
plot(Xf,(p<=alpha)*100-100+v(3)*.95,'r.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points

plot([v(1) v(2)],[0 0],'k--') % add horizontal line at zero

set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
    xlabel('Time in ms','FontSize',16)
    ylabel('Amplitude in \muV','FontSize',16)
    box on

% --------------------------------------------------------------------------
subplot(5,1,5);hold on % plot proportion of subjects with ERP>0

prop=sum(squeeze(c1-c2)>0,2)./size(c1,3);
% prop=max([sum(squeeze(c1-c2)>0,2) sum(squeeze(c1-c2)<0,2)],[],2)./size(c1,3);

plot(Xf,prop,'Color',[1 0 0],'LineStyle','-','LineWidth',3)

set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
    xlabel('Time in ms','FontSize',16)
    ylabel({'Proportion';'of subjects'},'FontSize',16)
    box on
plot([v(1) v(2)],[.5 .5],'k--') % add horizontal line at 0.5
