%% erp_workshop_4_percentile_bootstrap

%% ************************************************************************
%% CASE STUDY 1: OUTLIERS **************************************************
%% ************************************************************************

%% PREPARE DATA

load casestudy1
c2 = c2c;
diff = c1-c2;

[~,Nf,Ns] = size(c2);

%% BOOTSTRAP ESTIMATES OF THE DIFFERENCE BETWEEN CONDITIONS

% Strategy: 
% [1] sample subjects with replacement
% [2] average observations
% [3] repeat steps [1-2] Nb times
% [4] sort the results and get confidence interval around the difference

Nb = 100; % number of bootstrap samples - don't use too many at this stage!
alpha = .05; % alpha level
lo = round(Nb*alpha/2); % threshold 
hi = Nb-lo;
mu = 0; % our null hypothesis

bootdiff = zeros(Nf,Nb);

for B = 1:Nb % bootstrap loop
    bootdiff(:,B) = mean(diff(:,:,randi(Ns,Ns,1)),3); % sample subjects with replacement and average
end

sortbootdiff = sort(bootdiff,2); % sort bootstrapped differences
CI=zeros(Nf,2);
CI(:,1) = sortbootdiff(:,lo+1); % confidence interval
CI(:,2) = sortbootdiff(:,hi);
p = sum(bootdiff>mu,2)./Nb;
p = 2.*min(p,1-p); % a vector of p values

% We could also use the function limo_pbci
% [EST,CI,p] = limo_pbci(diff,Nb,alpha,0,'mean');

%% PLOT RESULTS

percent = 0; % regular t-test

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,mean(c1,3),'Color',[0 0 0],'LineStyle','-','LineWidth',2)
plot(Xf,mean(c2,3),'Color',[.7 .7 .7],'LineStyle','--','LineWidth',2)
plot(Xf,mean(c1,3)-mean(c2,3),'Color','r','LineStyle','-','LineWidth',3)
plot(Xf,squeeze(CI),'Color','r','LineStyle','-','LineWidth',1)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on
v=axis; % get current axis limits
plot(Xf,(squeeze(p)<=alpha)*100-100+v(3)*.95,'r.','MarkerSize',10)
% compare to t-test results
[t,diff,se,CI,ttestp,tcrit,df]=limo_yuend_ttest(c1,c2,percent,alpha);
plot(Xf,(squeeze(ttestp)<=alpha)*100-100+v(3)*.99,'g.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points

%% ************************************************************************
%% CASE STUDY 2: CHANGE IN SPREAD, NOT IN LOCATION ************************
%% ************************************************************************

%% PREPARE DATA

load casestudy2

percent = 0; % regular t-test
alpha = 0.05;
[t,diff,se,CI,p,tcrit,df]=limo_yuend_ttest(c1,c2,percent,alpha);

C1 = mean(c1,3); % average across subjects for condition 1
C2 = mean(c2,3); % average across subjects for condition 2


%% BOOTSTRAP ESTIMATES OF THE VARIANCE DIFFERENCE BETWEEN CONDITIONS

% Strategy: 
% [1] sample subjects with replacement
% [2] compute variance of observations
% [3] repeat steps [1-2] Nb times
% [4] sort the results and get confidence interval around the variance

% ALTHOUGH THE METHOD DESCRIBED HERE SEEMS TO WORK, IT MIGHT NOT BE
% SATISFACTORY IN SOME SITUATIONS - SEE WILCOX 2012 PAGE 208

Nb=100; % number of bootstrap samples - don't use too many at this stage!
alpha=.05; % alpha level
lo=round(Nb*alpha/2); % threshold 
hi=Nb-lo;
mu=0; %our null hypothesis

bootdiff = zeros(Nf,Nb);

for B=1:Nb % bootstrap loop
    bootsample=randi(Ns,Ns,1);%sample subjects with replacement
    bootdiff(:,B)=var(c1(:,:,bootsample),0,3)-var(c2(:,:,bootsample),0,3); 
end

sortbootdiff = sort(bootdiff,2); % sort bootstrapped differences
CI=zeros(Nf,2);
CI(:,1) = sortbootdiff(:,lo+1); % confidence interval
CI(:,2) = sortbootdiff(:,hi);

%% PLOT RESULTS

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,var(c1,0,3),'Color',[0 0 0],'LineStyle','-','LineWidth',2)
plot(Xf,var(c2,0,3),'Color',[.7 .7 .7],'LineStyle','--','LineWidth',2)
plot(Xf,var(c1,0,3)-var(c2,0,3),'Color','r','LineStyle','-','LineWidth',3)
plot(Xf,squeeze(CI),'Color','r','LineStyle','-','LineWidth',1)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('ERP variance','FontSize',16)
box on

