%% erp_workshop_7_cmc_group

%% PREPARE DATA

c1=zeros(1,451,20);c2=c1; % reformat data so that dimension 1 = 1 electrode
c1(1,:,:)=erpm(:,:,1); c2(1,:,:)=erpm(:,:,2);
percent=0; % regular t-test
alpha=.05; % alpha level
[orit,diff,se,CI,orip,tcrit,df]=limo_yuend_ttest(c1,c2,percent,alpha);

Xf=-300:2:600; % time vector
Nf=length(Xf); % number of time frames
Ns=size(c1,3);

%% BOOTSTRAP

Nb=100; % number of bootstrap samples - don't use too many at this stage!
th=Nb*(1-alpha); % threshold 

boott = zeros(Nf,Nb);
bootp = boott;
cc1 = c1-repmat(mean(c1,3),[1 1 Ns]); % centre condition 1
cc2 = c2-repmat(mean(c2,3),[1 1 Ns]); % centre condition 2

for B = 1:Nb % bootstrap loop
    bootsample=randi(Ns,Ns,1); % sample subjects with replacement
    [boott(:,B),diff,se,CI,bootp(:,B),tcrit,df]=limo_yuend_ttest(cc1(:,:,bootsample),cc2(:,:,bootsample),percent,alpha);
end
    
%% GET BOOTSTRAP UNIVARIATE THREHOLDS & MAKE FIGURE

% Here we look at the t-test results in which we used 
% our own data-driven t table

sortboot = sort(boott.^2,2); % t.^2 = F 
unibootth = sortboot(:,th); 

C1=mean(erpm(:,:,1),2); % average across subjects for condition 1
C2=mean(erpm(:,:,2),2); % average across subjects for condition 2

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',1)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',1)
plot(Xf,C1-C2,'Color','r','LineStyle','-','LineWidth',3)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on
v=axis; % get current axis limits
plot(Xf,(orit.^2>=unibootth')*100-100+v(3)*.95,'r.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points

%% CORRECT FOR MULTIPLE COMPARISONS 

% get cluster threshold
clusterbootth = limo_ecluster_make(boott.^2,bootp,alpha);

%cluster original data
sigcluster = limo_ecluster_test(orit.^2,orip,clusterbootth,alpha);

%% PLOT RESULTS

% Looks like all the false positives in the baseline are gone.

figure('Color','w','NumberTitle','off') % make blank figure
hold on % we're going to plot several elements
plot(Xf,C1,'Color',[0 0 0],'LineStyle','-','LineWidth',1)
plot(Xf,C2,'Color',[.7 .7 .7],'LineStyle','--','LineWidth',1)
plot(Xf,C1-C2,'Color','r','LineStyle','-','LineWidth',3)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 600])
xlabel('Time in ms','FontSize',16)
ylabel('Amplitude in \muV','FontSize',16)
box on
v=axis; % get current axis limits
plot(Xf,sigcluster.elec_mask*100-100+v(3)*.95,'r.','MarkerSize',10)
axis(v) % restore axis limits to hide non-significant points

%% EXERCISE: CHECK WHAT YOU GET WHEN YOU TRIM THE DATA



