%% erp_workshop_9_cmc_single

%% GET DATA

% load data from one subject

S=1; % load S1 or S2
filename=['S',num2str(S),'_allelec_epoch.set'];
% filepath='yourpath/erp_workshop/dataset/';
EEG = pop_loadset('filename',filename,'filepath',filepath);
Ne = EEG.nbchan;

%% GET NEIGHBOURHOOD MATRIX

neighbourdist=0.37; % good threshold for the standard 128 channel Biosemi cap
[neighbours,channeighbstructmat] = limo_get_channeighbstructmat(EEG,neighbourdist);

% figure;imagesc(channeighbstructmat)
% neighbours{1}
% neighbours{1}.neighblabel

%% BOOTSTRAP

alpha = 0.05;
nboot = 50; % < keep it small for now - will take a while!
minnbchan = 2;

ev=[EEG.epoch.eventtype]; % get triggers 
data1 = EEG.data(:,:,ev<115);
data2 = EEG.data(:,:,ev>=115);

[Ty,diff,CI,p,tcrit,df,ori_mask,boot_mask,cluster_mask]=...
    limo_yuen_ttest_boot(data1,data2,percent,alpha,nboot,minnbchan,channeighbstructmat);

%% SINGLE-SUBJECT RESULTS AT ALL ELECTRODES:
% colour coded 2D representation of t values using imagesc

figure('Color','w','NumberTitle','off');hold on 

imagesc(EEG.times,1:Ne,Ty) % map of t values
h = imagesc(EEG.times,1:Ne,ones([size(Ty) 3]).*.9); % superimpose grey mask
set(h, 'AlphaData', cluster_mask*-1+1) % reveal significant t values through mask

title('t values','FontSize',18)
xlabel('Time in ms','FontSize',16)
ylabel('Electrodes','FontSize',16)
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 400],'YLim',[1 Ne])
set(gca,'Layer','Top','YTick',1:Ne,'YTickLabel','')
box on

%% SINGLE-SUBJECT RESULTS AT ALL ELECTRODES:
% all t values superimposed

figure('Color','w','NumberTitle','off');hold on 

plot(EEG.times,Ty,'k')
set(gca,'LineWidth',1,'FontSize',14,'XLim',[-300 400],'Layer','top')
box on
title('t values','FontSize',18)

%% SINGLE-SUBJECT RESULTS AT ALL ELECTRODES:
% all t values superimposed + max across electrodes
% show significant effects across electrodes

sig=sum(cluster_mask,1)>0;

figure('Color','w','NumberTitle','off');hold on 

plot(EEG.times,Ty,'Color',[.7 .7 .7])
plot(EEG.times,max(Ty,[],1),'Color','k','LineWidth',3)
v=axis;
plot(EEG.times,sig*100-100,'r.','MarkerSize',10)
set(gca,'LineWidth',1,'FontSize',14)
set(gca,'XLim',[-300 400],'YLim',[v(3) v(4)],'Layer','top')
box on
title('t values','FontSize',18)

%% SINGLE-SUBJECT RESULTS AT ALL ELECTRODES:
% topographic maps of t values

% enter time frames 
frame_select = 100:5:130; % check: EEG.times(100)

figure('Color','w','NumberTitle','off');hold on 

for sub=1:length(frame_select)
    subplot(1,length(frame_select),sub)
    topoplot(Ty(:,frame_select(sub)),EEG.chanlocs,'shading','interp')
    title([num2str(EEG.times(frame_select(sub))),' ms'],'FontSize',18)
end



